:tocdepth: 2

.. _authors:

authors
=======

PiCast is written and maintained by Hiroshi Miura <miurahr@linux.com>

Original lazycast is written by Hsun-Wei Cho and its contributors

Contributors, listed alphabetically, are:

Anton Panikov,
